@@ -184,6 +184,29 @@ gsm_check_for_root (void)
   return !(response == ROOTSESSION_RESPONSE_CONTINUE);
 }
 
+static void
+gsm_breakpad_set_gtk_modules (void)
+{
+  gchar *path;
+  const gchar *old_env;
+  gchar *new_env;
+
+  path = g_find_program_in_path ("bug-buddy");
+  if (!path)
+    return;
+
+  g_free (path);
+
+  old_env = g_getenv ("GTK_MODULES");
+  if (old_env)
+    new_env = g_strconcat (old_env, ":gnomebreakpad", NULL);
+  else
+    new_env = g_strdup ("gnomebreakpad");
+  
+  g_setenv ("GTK_MODULES", new_env, TRUE);
+  g_free (new_env);
+}
+
 #define FALLBACK_TIME_UTILITY "time-admin"
 #define CLOCKSESSION_RESPONSE_IGNORE 1
 #define CLOCKSESSION_RESPONSE_ADJUST 3
@@ -198,11 +221,25 @@ struct check_clock {
 static gboolean
 gsm_check_time (void)
 {
-  time_t now;
+  int    cmp;
+  GDate *now;
+  GDate *tarball;
 
-  now = time (NULL);
+  now = g_date_new ();
+  g_date_set_time_t (now, time(NULL));
+
+  tarball = g_date_new_dmy (GNOME_SESSION_TARBALL_DAY,
+                            GNOME_SESSION_TARBALL_MONTH,
+                            GNOME_SESSION_TARBALL_YEAR);
   /* accept a one week error: no need to be too strict */
-  return (now > GNOME_COMPILE_TIME - 3600*24*7);
+  g_date_subtract_days (tarball, 7);
+
+  cmp = g_date_compare (now, tarball);
+
+  g_date_free (now);
+  g_date_free (tarball);
+
+  return (cmp > 0);
 }
 
 static void
@@ -295,7 +332,8 @@ gsm_check_clock_tool_exited (GPid     pid,
                              gint     status,
                              gpointer data)
 {
-  gsm_check_clock_main_quit ((struct check_clock *) data);
+  if (gsm_check_time ())
+    gsm_check_clock_main_quit ((struct check_clock *) data);
 
   g_spawn_close_pid (pid);
 }
@@ -393,8 +431,7 @@ gsm_check_clock (void)
 
   gtk_widget_show (check.dialog);
 
-  check.timeout_id = g_timeout_add (1000 * 60,
-                                    gsm_check_clock_update, &check);
+  check.timeout_id = g_timeout_add_seconds (30, gsm_check_clock_update, &check);
 
   gtk_main ();
 }
@@ -638,6 +675,8 @@ main (int argc, char *argv[])
         }
     }
   
+  gsm_breakpad_set_gtk_modules ();
+
   /* Read the config option early, so that we know if a11y is set or not */ 
   gconf_client = gsm_get_conf_client ();
   gconf_client_add_dir (gconf_client, GSM_GCONF_CONFIG_PREFIX, GCONF_CLIENT_PRELOAD_ONELEVEL, NULL); 
