@@ -21,7 +21,6 @@
 #define SPLASH_WIDGET_H
 
 #include <gtk/gtkwindow.h>
-#include <libgnomeui/gnome-icon-theme.h>
 
 #define SPLASH_TYPE_WIDGET                  (splash_widget_get_type ())
 #define SPLASH_WIDGET(obj)                  (GTK_CHECK_CAST ((obj), SPLASH_TYPE_WIDGET, SplashWidget))
@@ -30,11 +29,12 @@
 #define SPLASH_IS_WIDGET_CLASS(klass)       (GTK_CHECK_CLASS_TYPE ((klass), SPLASH_TYPE_WIDGET))
 #define SPLASH_WIDGET_GET_CLASS(obj)        (GTK_CHECK_GET_CLASS ((obj), SPLASH_TYPE_WIDGET, SplashWidgetClass))
 
+#define TRANS_TIMEOUT        50
+#define TRANS_TIMEOUT_PERIOD 30
+
 typedef struct  {
 	GtkWindow    window;
 
-        GnomeIconTheme *icon_theme;
-  
 	GdkPixbuf   *background;
 	GdkPixmap   *bg_pixmap;
 	GList       *icons;
